// MainForm.cpp
//
// This file implements the main form for
// your application.

#include "Common.h"
#include "MainForm.h"
#include "WideDisplaySampleApp.h"
#include "PenInputMgr.h"

// Form open handler
Boolean CMainForm::OnOpen(EventPtr pEvent, Boolean& bHandled) {
	UInt32 version;
	Err err = ::FtrGet( pinCreator, pinFtrAPIVersion, &version );
	if( !err && version ) {
		::FrmSetDIAPolicyAttr( GetFormPtr( ), frmDIAPolicyCustom );
		// Enable the input trigger
		err = ::PINSetInputTriggerState( pinInputTriggerEnabled );
		WinHandle frmHandle = ::FrmGetWindowHandle( GetFormPtr( ) );
		::WinSetConstraintsSize( frmHandle, 160, 225, 225, 160, 160, 225 );
	}
	bHandled = false;
	return true;
}

Boolean CMainForm::OnWinEnter(EventPtr pEvent, Boolean& bHandled) {
	UInt32 version;
	Err err = ::FtrGet( pinCreator, pinFtrAPIVersion, &version );
	if( !err && version ) {
		FrmSetDIAPolicyAttr( GetFormPtr( ), frmDIAPolicyCustom );
		// Enable the input trigger
		err = ::PINSetInputTriggerState( pinInputTriggerEnabled );
		WinHandle frmHandle = ::FrmGetWindowHandle( GetFormPtr( ) );
		::WinSetConstraintsSize( frmHandle, 160, 225, 225, 160, 160, 225 );
	}
	bHandled = false;
	return true;
}

Boolean CMainForm::OnOpenPost(EventPtr pEvent, Boolean& bHandled) {
	ReCalcLayout( );
	bHandled = false;
	return true;
}

Boolean CMainForm::OnDisplayChanged(EventPtr pEvent, Boolean& bHandled) {
	ReCalcLayout( );
	bHandled = false;
	return true;
}

void CMainForm::ReCalcLayout( ) {

	// get the current bounds for the form
	FormType* pForm = ::FrmGetActiveForm( );

	RectangleType displayBounds;
	RectangleType formBounds;
	WinHandle frmHandle = ::FrmGetWindowHandle( pForm );
	::WinGetBounds( frmHandle, &formBounds );					// current form bounds
	::WinGetBounds( ::WinGetDisplayWindow( ), &displayBounds );	// new display window bounds

//	::SndPlaySystemSound( sndClick );	// for debug...

	if( !::MemCmp( &formBounds, &displayBounds, sizeof(RectangleType) ) )
		return;

	::WinSetBounds( frmHandle, &displayBounds );

	CButton button;
	RectangleType rect;
	
	button.Attach( MAINFORMTOPBUTTON );
	button.GetObjectBounds( rect );
	rect.topLeft.x = ( displayBounds.extent.x - rect.extent.x ) / 2;
	rect.topLeft.y = 22;
	button.SetObjectBounds( rect );
	button.Detach( );

	button.Attach( MAINFORMBOTTOMBUTTON );
	button.GetObjectBounds( rect );
	rect.topLeft.x = ( displayBounds.extent.x - rect.extent.x ) / 2;
	rect.topLeft.y = displayBounds.extent.y - rect.extent.y - 4;
	button.SetObjectBounds( rect );
	button.Detach( );

	button.Attach( MAINFORMLEFTBUTTON );
	button.GetObjectBounds( rect );
	rect.topLeft.x = 4;
	rect.topLeft.y = ( displayBounds.extent.y - rect.extent.y ) / 2;
	button.SetObjectBounds( rect );
	button.Detach( );

	button.Attach( MAINFORMRIGHTBUTTON );
	button.GetObjectBounds( rect );
	rect.topLeft.x = displayBounds.extent.x - rect.extent.x - 4;
	rect.topLeft.y = ( displayBounds.extent.y - rect.extent.y ) / 2;
	button.SetObjectBounds( rect );
	button.Detach( );

	::FrmDrawForm( pForm );

}
